#
# spec file for package kube-linter
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kube-linter
Version:        0.6.5
Release:        1.1
Summary:        Static analysis tool that checks Kubernetes YAML files and Helm charts
License:        Apache-2.0
URL:            https://github.com/stackrox/kube-linter
Source:         kube-linter-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19

%description
KubeLinter analyzes Kubernetes YAML files and Helm charts, and checks them against a variety of best practices, with a focus on production readiness and security.

KubeLinter runs sensible default checks, designed to give you useful information about your Kubernetes YAML files and Helm charts. This is to help teams check early and often for security misconfigurations and DevOps best practices. Some common examples of these include running containers as a non-root user, enforcing least privilege, and storing sensitive information only in secrets.

KubeLinter is configurable, so you can enable and disable checks, as well as create your own custom checks, depending on the policies you want to follow within your organization.

When a lint check fails, KubeLinter reports recommendations for how to resolve any potential issues and returns a non-zero exit code.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-s -w -X golang.stackrox.io/kube-linter/internal/version.version=v%{version}" \
   -o bin/kube-linter ./cmd/kube-linter

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Thu Nov  2 2023 kastl@b1-systems.de
- Update to version 0.6.5:
  * Add OpenShift SecurityContextConstraints object linting (#650)
  * Bump github.com/cert-manager/cert-manager from 1.13.1 to 1.13.2
    (#653)
  * Bump github.com/docker/docker (#652)
  * Bump google.golang.org/grpc from 1.58.2 to 1.58.3 (#648)
  * Bump github.com/golangci/golangci-lint from 1.54.0 to 1.55.1
    (#646)
  * Bump github.com/bmatcuk/doublestar/v4 from 4.6.0 to 4.6.1
    (#647)
  * Bump k8s.io/cli-runtime from 0.28.2 to 0.28.3 (#645)
  * Bump helm.sh/helm/v3 from 3.13.0 to 3.13.1 (#643)
  * Bump docker/login-action from 2.2.0 to 3.0.0 (#640)
  * Bump golang.org/x/net from 0.15.0 to 0.17.0 (#641)
  * Bump github.com/spf13/viper from 1.16.0 to 1.17.0 (#639)
  * Bump
    github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring
    (#638)
  * Bump github.com/owenrumney/go-sarif/v2 from 2.2.2 to 2.3.0
    (#636)
  * add dangling service monitor check (#547)
  * Bump docker/build-push-action from 4.1.1 to 5.0.0 (#626)
  * Bump docker/setup-buildx-action from 2.10.0 to 3.0.0 (#627)
  * Bump docker/metadata-action from 4.6.0 to 5.0.0 (#628)
  * Bump helm.sh/helm/v3 from 3.12.3 to 3.13.0 (#635)
  * Bump k8s.io/cli-runtime from 0.28.1 to 0.28.2 (#632)
  * Bump github.com/cert-manager/cert-manager from 1.13.0 to 1.13.1
    (#634)
  * Bump k8s.io/client-go from 0.28.1 to 0.28.2 (#633)
  * Bump k8s.io/api from 0.28.1 to 0.28.2 (#631)
  * Bump k8s.io/apimachinery from 0.28.1 to 0.28.2 (#630)
  * Bump github.com/owenrumney/go-sarif/v2 from 2.2.0 to 2.2.2
    (#629)
  * Bump github.com/cert-manager/cert-manager from 1.12.4 to 1.13.0
    (#625)
  * Bump github.com/cyphar/filepath-securejoin from 0.2.3 to 0.2.4
    (#624)
  * Bump actions/checkout from 3 to 4 (#622)
  * Bump sigstore/cosign-installer from 3.1.1 to 3.1.2 (#623)
  * Bump github.com/cert-manager/cert-manager from 1.12.3 to 1.12.4
    (#620)
  * Bump k8s.io/cli-runtime from 0.28.0 to 0.28.1 (#621)
  * Bump docker/setup-buildx-action from 2.9.1 to 2.10.0 (#619)
  * Bump k8s.io/client-go from 0.28.0 to 0.28.1 (#617)
  * Bump k8s.io/cli-runtime from 0.27.4 to 0.28.0 (#615)
  * make docs match example for custom required-annotation (#614)
  * Bump helm.sh/helm/v3 from 3.12.2 to 3.12.3 (#612)
  * Bump github.com/golangci/golangci-lint from 1.53.3 to 1.54.0
    (#610)
  * Bump github.com/cert-manager/cert-manager from 1.12.2 to 1.12.3
    (#607)
  * Bump k8s.io/cli-runtime from 0.27.3 to 0.27.4 (#602)
  * Bump k8s.io/client-go from 0.27.3 to 0.27.4 (#604)
  * Bump github.com/docker/docker (#601)
  * Bump helm.sh/helm/v3 from 3.12.1 to 3.12.2 (#600)
  * Bump docker/setup-buildx-action from 2.8.0 to 2.9.1 (#597)
  * updated pre commit hook docker image version (#595)
  * Bump github.com/golangci/golangci-lint from 1.53.2 to 1.53.3
    (#594)
  * Bump docker/setup-buildx-action from 2.7.0 to 2.8.0 (#593)
  * Bump sigstore/cosign-installer from 3.0.5 to 3.1.1 (#592)
  * Bump k8s.io/cli-runtime from 0.27.2 to 0.27.3 (#589)
  * Bump github.com/cert-manager/cert-manager from 1.12.1 to 1.12.2
    (#590)
  * Bump helm.sh/helm/v3 from 3.12.0 to 3.12.1 (#588)
  * Bump docker/build-push-action from 4.0.0 to 4.1.1 (#585)
  * Bump docker/metadata-action from 4.5.0 to 4.6.0 (#587)
  * Bump docker/setup-buildx-action from 2.6.0 to 2.7.0 (#586)
  * Bump docker/metadata-action from 4.4.0 to 4.5.0 (#582)
  * Bump github.com/spf13/viper from 1.15.0 to 1.16.0 (#583)
  * Bump github.com/golangci/golangci-lint from 1.52.2 to 1.53.2
    (#584)
  * Bump docker/setup-buildx-action from 2.5.0 to 2.6.0 (#580)
  * Bump docker/login-action from 2.1.0 to 2.2.0 (#581)
  * Bump k8s.io/cli-runtime from 0.27.1 to 0.27.2 (#577)
  * Bump github.com/cert-manager/cert-manager from 1.11.2 to 1.12.1
    (#578)
  * Bump github.com/stretchr/testify from 1.8.3 to 1.8.4 (#579)
  * Bump github.com/stretchr/testify from 1.8.2 to 1.8.3 (#571)
  * Bump k8s.io/client-go from 0.27.1 to 0.27.2 (#572)
  * Bump sigstore/cosign-installer from 3.0.4 to 3.0.5 (#570)
  * Fix get tag (#568)
  * Bump github.com/owenrumney/go-sarif/v2 from 2.1.3 to 2.2.0
    (#567)
  * Bump sigstore/cosign-installer from 3.0.3 to 3.0.4 (#566)
* Mon Oct  9 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kube-linter: static analysis tool that checks
  Kubernetes YAML files and Helm charts
